@@ -7,33 +7,38 @@
 #' daily_response function
 #' @param window_width integer representing window width to be displayed
 #' @param title logical, if set to FALSE, no plot title is displayed
+#' @param ylimits limit of the y axes. It should be given as ylimits = c(0,1)
 #'
 #' @return A ggplot2 object containing the plot display
-#' @export
 #'
 #' @examples
-#' \dontrun{
+#' }
 #' data(LJ_daily_temperatures)
+#' data(KRE_daily_temperatures)
 #' data(example_proxies_1)
 #' Example1 <- daily_response(response = example_proxies_1,
-#' env_data = LJ_daily_temperatures, method = "lm", measure = "r.squared",
-#' lower_limit = 90, upper_limit = 150)
+#' env_data = LJ_daily_temperatures, method = "lm", metric = "r.squared",
+#' lower_limit = 90, upper_limit = 150, row_names_subset = TRUE,
+#' previous_year = TRUE)
 #' plot_specific(Example1, window_width = 90)
 #'
-#' Example2 <- daily_response(response = example_proxies_1,
-#' env_data = LJ_daily_temperatures, method = "brnn",
-#' measure = "adj.r.squared", lower_limit = 150, upper_limit = 155,
-#' neurons = 1)
+#' Example2 <- daily_response(response = data_TRW_1,
+#' env_data = KRE_daily_temperatures, method = "cor",
+#' metric = "adj.r.squared", lower_limit = 150, upper_limit = 155,
+#' neurons = 1, row_names_subset = TRUE, previous_year = TRUE)
 #' plot_specific(Example2, window_width = 153, title = TRUE)
 #'
 #' Example3 <- daily_response(response = example_proxies_1,
 #' env_data = LJ_daily_temperatures, method = "brnn",
-#' measure = "adj.r.squared", lower_limit = 150, upper_limit = 155,
-#' neurons = 1, previous_year = TRUE)
+#' metric = "adj.r.squared", lower_limit = 150, upper_limit = 155,
+#' neurons = 1, previous_year = TRUE, row_names_subset = TRUE)
 #' plot_specific(Example3, window_width = 153, title = TRUE)
 #' }
+#'
+#' @keywords internal
 
-plot_specific <- function(result_daily_response, window_width, title = TRUE) {
+plot_specific <- function(result_daily_response, window_width, title = TRUE,
+                          ylimits = NULL) {
 
   # Short description of the function. It
   # - extracts matrix (the frst object of a list)
@@ -108,7 +113,7 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     # index represent the starting day (location) in the matrix, which gives
     # the maximum result
     max_result <- max(temporal_vector, na.rm = TRUE)
-    calculated_measure <- round(max_result, 3)
+    calculated_metric <- round(max_result, 3)
     index <- which(temporal_vector$var1 == max_result, arr.ind = TRUE)
     plot_column <- index
   }
@@ -120,7 +125,7 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     # index represent the starting day (location) in the matrix, which gives
     # the minimum result
     min_result <- min(temporal_vector, na.rm = TRUE)
-    calculated_measure <- round(min_result, 3)
+    calculated_metric <- round(min_result, 3)
     index <- which(temporal_vector$var1 == min_result, arr.ind = TRUE)
     plot_column <- index
   }
@@ -149,16 +154,32 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
       theme(plot.title = element_blank())
   }
 
-  final_plot <- ggplot(temporal_vector, aes_(y = ~var1,
+
+  # Here we define a data frame of dates and corresponing day of year (doi). Later
+  # this dataframe will be used to describe tht optimal sequence od days
+  doy <- seq(1:366)
+  date <- seq(as.Date('2013-01-01'),as.Date('2013-12-31'), by = "+1 day")
+  date[366] <- as.Date('2015-12-31')
+  date <- format(date, "%b %d")
+  date_codes <- data.frame(doy = doy, date = date)
+
+
+  Optimal_string <- paste("\nOptimal Selection:",
+                          as.character(date_codes[plot_column_extra, 2]),"-",
+                          as.character(date_codes[plot_column_extra + as.numeric(window_width) - 1, 2]))
+
+  final_plot <- suppressWarnings(
+  ggplot(temporal_vector, aes_(y = ~var1,
     x = ~ seq(1, nrow(temporal_vector)))) + geom_line(lwd = 1.2) +
     geom_vline(xintercept = plot_column, col = "red", size = 1) +
     scale_x_continuous(breaks = sort(c(seq(0, nrow(temporal_vector), 50)), decreasing = FALSE),
       labels = sort(c(seq(0, nrow(temporal_vector), 50)))) +
-    annotate("label", label = as.character(calculated_measure),
-      y = calculated_measure, x = plot_column + 15) +
+  scale_y_continuous(limits = ylimits) +
+    annotate("label", label = as.character(calculated_metric),
+      y = calculated_metric, x = plot_column + 15) +
     annotate("label", label = paste("Day", as.character(plot_column), sep = " "),
              y = min(temporal_vector, na.rm = TRUE) + 0.2*min(temporal_vector, na.rm = TRUE), x = plot_column + 15) +
-    journal_theme
+    journal_theme)
 
   # If previous_year = TRUE, we add a vertical line with labels of
   # previous and current years
@@ -166,26 +187,26 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     final_plot <- final_plot +
       annotate(fontface = "bold", label = 'Previous Year', geom = 'label',
                x = 366 - ncol(result_daily_element1) / 12.8,
-               y = calculated_measure - (calculated_measure/5)) +
+               y = calculated_metric - (calculated_metric/5)) +
       annotate(fontface = "bold", label = 'Current Year', geom = 'label',
                x = 366 + ncol(result_daily_element1) / 13.5,
-               y = calculated_measure -(calculated_measure/5)) +
+               y = calculated_metric -(calculated_metric/5)) +
       geom_vline(xintercept = 366, size = 1)
   }
 
 
   # Here we define titles. They differ importantly among methods and arguments
   # in the final output list from daily_response() function
-  if (is.na(result_daily_response[[5]])) {
+  if (is.na(result_daily_response[[4]])) {
 
 
     if ((nrow(temporal_vector) > 366) &&  (plot_column > 366) &&
         (result_daily_response [[2]] == "cor")) {
       final_plot <- final_plot +
-        ggtitle(paste("Maximal correlation coefficient:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+        ggtitle(paste("Maximal correlation coefficient:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Correlation Coefficient")
     }
@@ -193,10 +214,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     if ((nrow(temporal_vector) > 366) &&  (plot_column < 366) &&
         (result_daily_response [[2]] == "cor")) {
       final_plot <- final_plot +
-        ggtitle(paste("Maximal correlation coefficient:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of previous year")) +
+        ggtitle(paste("Maximal correlation coefficient:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Previous Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Correlation Coefficient")
     }
@@ -204,10 +226,10 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     if ((nrow(temporal_vector) < 366) &&
         (result_daily_response [[2]] == "cor")) {
       final_plot <- final_plot +
-        ggtitle(paste("Maximal correlation coefficient:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+        ggtitle(paste("Maximal correlation coefficient:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Correlation Coefficient")
     }
@@ -224,10 +246,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[3]] == "r.squared")) {
       final_plot <- final_plot +
         ggtitle(paste("Method: Linear Regression",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -238,11 +261,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "brnn") &&
         (result_daily_response [[3]] == "r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Method: ANN with Bayesian Regularization",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+        ggtitle(paste("Method: ANN With Bayesian Regularization",
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -258,10 +281,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
         ggtitle(paste("Method: Linear Regression",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of previous year")) +
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Previous Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -270,11 +294,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "brnn") &&
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
-        ggtitle(paste("Method: ANN with Bayesian Regularization",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of previous year")) +
+        ggtitle(paste("Method: ANN With Bayesian Regularization",
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Previous Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -290,10 +315,10 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
         ggtitle(paste("Method: Linear Regression",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Explained Variance")
     }
@@ -302,11 +327,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "brnn") &&
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
-        ggtitle(paste("Method: ANN with Bayesian Regularization",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+        ggtitle(paste("Method: ANN With Bayesian Regularization",
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Explained Variance")
     }
@@ -327,10 +352,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
         ggtitle(paste("Method: Linear Regression",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -342,11 +368,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "brnn") &&
         (result_daily_response[[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Method: ANN with Bayesian Regularization",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+        ggtitle(paste("Method: ANN With Bayesian Regularization",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -364,11 +391,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
         ggtitle(paste("Method: Linear Regression",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
                       plot_column_extra,
-                      "of previous year")) +
+                      "of Previous Year", Optimal_string, "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -377,12 +404,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "brnn") &&
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Method: ANN with Bayesian Regularization",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
+        ggtitle(paste("Method: ANN With Bayesian Regularization",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
                       plot_column_extra,
-                      "of previous year")) +
+                      "of Previous Year", Optimal_string, "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -402,10 +429,10 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
         ggtitle(paste("Method: Linear Regression",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Adjusted Explained Variance")
     }
@@ -414,11 +441,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "brnn") &&
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Method: ANN with Bayesian Regularization",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+        ggtitle(paste("Method: ANN With Bayesian Regularization",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Adjusted Explained Variance")
     }
@@ -427,17 +454,17 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
   }
 
 
-  if (!is.na(result_daily_response[[5]])) {
+  if (!is.na(result_daily_response[[4]])) {
 
 
     if ((nrow(temporal_vector) > 366) &&  (plot_column > 366) &&
         (result_daily_response [[2]] == "cor")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMaximal correlation coefficient:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMaximal correlation coefficient:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Correlation Coefficient")
     }
@@ -445,11 +472,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     if ((nrow(temporal_vector) > 366) &&  (plot_column < 366) &&
         (result_daily_response [[2]] == "cor")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMaximal correlation coefficient:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of previous year")) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMaximal correlation coefficient:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Previous Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Correlation Coefficient")
     }
@@ -457,11 +485,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
     if ((nrow(temporal_vector) < 366) &&
         (result_daily_response [[2]] == "cor")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMaximal correlation coefficient:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMaximal correlation coefficient:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Correlation Coefficient")
     }
@@ -477,12 +505,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "lm") &&
         (result_daily_response [[3]] == "r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
                       "\nMethod: Linear Regression",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -493,12 +521,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "brnn") &&
         (result_daily_response [[3]] == "r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMethod: ANN with Bayesian Regularization",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMethod: ANN With Bayesian Regularization",
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -513,12 +541,13 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "lm") &&
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
                       "\nMethod: Linear Regression",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of previous year")) +
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Previous Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -527,12 +556,13 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "brnn") &&
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMethod: ANN with Bayesian Regularization",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of previous year")) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMethod: ANN With Bayesian Regularization",
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Previous Year", Optimal_string,
+                      "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Explained Variance")
     }
@@ -547,12 +577,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "lm") &&
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
                       "\nMethod: Linear Regression",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Explained Variance")
     }
@@ -561,12 +591,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "brnn") &&
         result_daily_response[[3]] == "r.squared") {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMethod: ANN with Bayesian Regularization",
-                      "\nMaximal R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMethod: ANN With Bayesian Regularization",
+                      "\nMaximal R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Explained Variance")
     }
@@ -586,12 +616,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "lm") &&
         (result_daily_response[[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
                       "\nMethod: Linear Regression",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -603,12 +633,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response[[2]] == "brnn") &&
         (result_daily_response[[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMethod: ANN with Bayesian Regularization",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra, "of current year")) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMethod: ANN With Bayesian Regularization",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, "of Current Year", Optimal_string)) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -625,13 +655,13 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "lm") &&
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
                       "\nMethod: Linear Regression",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
                       plot_column_extra,
-                      "of previous year")) +
+                      "of Previous Year", Optimal_string, "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -640,13 +670,13 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "brnn") &&
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMethod: ANN with Bayesian Regularization",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMethod: ANN With Bayesian Regularization",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
                       plot_column_extra,
-                      "of previous year")) +
+                      "of Previous Year", Optimal_string, "(Previous Year)")) +
         xlab("Day of Year  (Including Previous Year)") +
         ylab("Adjusted Explained Variance")
     }
@@ -665,12 +695,12 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "lm") &&
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
                       "\nMethod: Linear Regression",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Adjusted Explained Variance")
     }
@@ -679,21 +709,17 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE) {
         (result_daily_response [[2]] == "brnn") &&
         (result_daily_response [[3]] == "adj.r.squared")) {
       final_plot <- final_plot +
-        ggtitle(paste("Analysed period:", result_daily_response[[5]],
-                      "\nMethod: ANN with Bayesian Regularization",
-                      "\nMaximal Adjusted R squared:", calculated_measure,
-                      "\nSelected window width:", window_width, "days",
-                      "\nStarting day of selected window width: day",
-                      plot_column_extra)) +
+        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
+                      "\nMethod: ANN With Bayesian Regularization",
+                      "\nMaximal Adjusted R Squared:", calculated_metric,
+                      "\nSelected Window Width:", window_width, "Days",
+                      "\nStarting Day of Selected Window Width: Day",
+                      plot_column_extra, Optimal_string)) +
         xlab("Day of Year") +
         ylab("Adjusted Explained Variance")
     }
 
-
-
   }
 
-
-
   final_plot
 }
